@@ -1,3 +1,7 @@
+"""
+ANDES command-line interface and argument parsers.
+"""
+
 import argparse
 import sys
 import os
@@ -12,6 +16,11 @@ from andes.routines import routine_cli
 
 logger = logging.getLogger(__name__)
 
+command_aliases = {
+    'prepare': ['prep'],
+    'selftest': ['st'],
+    }
+
 
 def create_parser():
     """
@@ -30,7 +39,8 @@ def create_parser():
                                                              '[doc] quick documentation; '
                                                              '[misc] misc. functions; '
                                                              '[prepare] prepare the numerical code; '
-                                                             '[selftest] run self test.'
+                                                             '[selftest] run self test; '
+                                                             '[demo] show demos.',
                                         )
 
     run = sub_parsers.add_parser('run')
@@ -122,7 +132,7 @@ def create_parser():
     misc.add_argument('-r', '--recursive', help='Recursively clean outputs (combined useage with --clean)',
                       action='store_true')
 
-    prep = sub_parsers.add_parser('prepare')  # NOQA
+    prep = sub_parsers.add_parser('prepare', aliases=command_aliases['prepare'])
     prep_mode = prep.add_mutually_exclusive_group()
     prep_mode.add_argument('-q', '--quick', action='store_true',
                            help='quick codegen by skipping pretty prints')
@@ -132,14 +142,17 @@ def create_parser():
     prep.add_argument('--pycode-path', help='Save path for generated pycode')
     prep.add_argument('-m', '--models', nargs='*', help='model names to be individually prepared',
                       )
+    prep.add_argument('--ncpu', help='Number of parallel processes', type=int, default=os.cpu_count())
+    prep.add_argument('--nomp', help='Disable multiprocessing', action='store_true',)
     prep.add_argument('--incubate', help='Save generated pycode under the ANDES code directory to avoid codegen',
                       action='store_true')
 
-
-    selftest = sub_parsers.add_parser('selftest')  # NOQA
+    selftest = sub_parsers.add_parser('selftest', aliases=command_aliases['selftest'])
     selftest.add_argument('-q', '--quick', action='store_true',
                           help='quick selftest by skipping codegen')
 
+    demo = sub_parsers.add_parser('demo')  # NOQA
+
     return parser
 
 
@@ -159,8 +172,9 @@ def preamble():
                 r' /_/ \_\_||_\__,_\___/__/ | This program comes with ABSOLUTELY NO WARRANTY.' + '\n')
 
     log_path = find_log_path(logging.getLogger("andes"))
+
     if len(log_path):
-        logger.debug(f'Logging to file {log_path[0]}')
+        logger.debug('Logging to file "%s"', log_path[0])
 
 
 def main():
@@ -188,5 +202,10 @@ def main():
         parser.parse_args(sys.argv.append('--help'))
 
     else:
-        func = getattr(module, args.command)
+        cmd = args.command
+        for fullcmd, aliases in command_aliases.items():
+            if cmd in aliases:
+                cmd = fullcmd
+
+        func = getattr(module, cmd)
         return func(cli=True, **vars(args))
