@@ -9,13 +9,13 @@ Base class for building ANDES models.
 #  (at your option) any later version.
 #
 #  File name: model.py
-#  Last modified: 8/16/20, 7:27 PM
 
 import logging
-import scipy as sp
 
 from collections import OrderedDict
-from typing import Iterable, Sized, Callable, Union
+from typing import Iterable, Sized
+
+import scipy as sp
 
 from andes.core.block import Block
 from andes.core.common import ModelFlags, JacTriplet, Config
@@ -28,9 +28,12 @@ from andes.core.service import NumSelect, FlagValue, ParamCalc, InitChecker, Rep
 from andes.core.service import SwBlock
 from andes.core.symprocessor import SymProcessor
 from andes.core.var import BaseVar, Algeb, State, ExtAlgeb, ExtState
+
 from andes.shared import jac_names, jac_types, jac_full_names
 from andes.shared import np, pd
+
 from andes.utils.func import list_flatten
+from andes.utils.numba import to_jit
 
 logger = logging.getLogger(__name__)
 
@@ -370,14 +373,14 @@ class ModelData:
             if not isinstance(values, (int, float, str, np.floating)) and not isinstance(values, Iterable):
                 raise ValueError(f"value must be a string, scalar or an iterable, got {values}")
 
-            elif len(values) > 0 and not isinstance(values[0], (list, tuple, np.ndarray)):
+            if len(values) > 0 and not isinstance(values[0], (list, tuple, np.ndarray)):
                 values = (values,)
 
         elif isinstance(keys, Sized):
             if not isinstance(values, Iterable):
                 raise ValueError(f"value must be an iterable, got {values}")
 
-            elif len(values) > 0 and not isinstance(values[0], Iterable):
+            if len(values) > 0 and not isinstance(values[0], Iterable):
                 raise ValueError(f"if keys is an iterable, values must be an iterable of iterables. got {values}")
 
             if len(keys) != len(values):
@@ -1536,7 +1539,7 @@ class Model:
         """
         return self.docum.get(max_width=max_width, export=export)
 
-    def prepare(self, quick=False, pycode_path=None):
+    def prepare(self, quick=False, pycode_path=None, yapf_pycode=False):
         """
         Symbolic processing and code generation.
         """
@@ -1549,7 +1552,9 @@ class Model:
         self.syms.generate_jacobians()
         self.syms.generate_init()
 
-        self.syms.generate_pycode(pycode_path=pycode_path)
+        self.syms.generate_pycode(pycode_path=pycode_path,
+                                  yapf_pycode=yapf_pycode,
+                                  )
         if quick is False:
             self.syms.generate_pretty_print()
 
@@ -1597,10 +1602,10 @@ class Model:
         self.get_inputs(refresh=True)
 
         if self.system.config.warn_abnormal:
-            for name, item in self.services_icheck.items():
+            for item in self.services_icheck.values():
                 item.check()
 
-    def numba_jitify(self, parallel=False, cache=False):
+    def numba_jitify(self, parallel=False, cache=False, nopython=False):
         """
         Optionally convert `self.calls.f` and `self.calls.g` to
         JIT compiled functions.
@@ -1619,20 +1624,23 @@ class Model:
         if self.flags.jited is True:
             return
 
-        self.calls.f = self._jitify_func_only(self.calls.f, parallel=parallel, cache=cache)
-        self.calls.g = self._jitify_func_only(self.calls.g, parallel=parallel, cache=cache)
+        self.calls.f = to_jit(self.calls.f,
+                              parallel=parallel,
+                              cache=cache,
+                              nopython=nopython,
+                              )
+        self.calls.g = to_jit(self.calls.g,
+                              parallel=parallel,
+                              cache=cache,
+                              nopython=nopython,
+                              )
 
         for jname in self.calls.j:
-            self.calls.j[jname] = self._jitify_func_only(self.calls.j[jname],
-                                                         parallel=parallel, cache=cache)
+            self.calls.j[jname] = to_jit(self.calls.j[jname],
+                                         parallel=parallel, cache=cache)
 
         self.flags.jited = True
 
-    def _jitify_func_only(self, func: Union[Callable, None], parallel=False, cache=False):
-        import numba
-        if func is not None:
-            return numba.jit(func, parallel=parallel, cache=cache)
-
     def __repr__(self):
         dev_text = 'device' if self.n == 1 else 'devices'
 
