@@ -92,7 +92,7 @@ class SymProcessor:
 
         """
 
-        logger.debug(f'- Generating symbols for {self.class_name}')
+        logger.debug('- Generating symbols for %s', self.class_name)
 
         # clear symbols storage
         self.f_list, self.g_list = list(), list()
@@ -136,8 +136,6 @@ class SymProcessor:
         self.lambdify_func[0]['Indicator'] = lambda x: x
         self.lambdify_func[0]['imag'] = np.imag
         self.lambdify_func[0]['real'] = np.real
-        self.lambdify_func[0]['im'] = np.imag
-        self.lambdify_func[0]['re'] = np.real
         self.lambdify_func[0]['safe_div'] = safe_div
 
         self.vars_list = list(self.vars_dict.values())  # useful for ``.jacobian()``
@@ -154,7 +152,7 @@ class SymProcessor:
         return fs
 
     def generate_equations(self):
-        logger.debug(f'- Generating equations for {self.class_name}')
+        logger.debug('- Generating equations for %s', self.class_name)
 
         self.f_list, self.g_list = list(), list()
 
@@ -227,7 +225,7 @@ class SymProcessor:
         self.calls.s = s_calls
         self.calls.s_args = s_args
 
-    def generate_jacobians(self):
+    def generate_jacobians(self, diag_eps=1e-8):
         """
         Generate Jacobians and store to corresponding triplets.
 
@@ -241,7 +239,7 @@ class SymProcessor:
             val -> self.calls._vgy
 
         """
-        logger.debug(f'- Generating Jacobians for {self.class_name}')
+        logger.debug('- Generating Jacobians for %s', self.class_name)
 
         # clear storage
         self.df_syms, self.dg_syms = Matrix([]), Matrix([])
@@ -301,7 +299,13 @@ class SymProcessor:
             if var.diag_eps == 0.0:
                 continue
             elif var.diag_eps is True:
-                eps = self.parent.system.config.diag_eps
+                if self.get_system_config('diag_eps') is not None:
+                    eps = self.parent.system.config.diag_eps
+                elif diag_eps is not None:
+                    eps = diag_eps  # from function argument
+                else:
+                    eps = 1e-8
+
             else:
                 eps = var.diag_eps
 
@@ -319,7 +323,7 @@ class SymProcessor:
         """
         Generate pretty print variables and equations.
         """
-        logger.debug(f"- Generating pretty prints for {self.class_name}")
+        logger.debug("- Generating pretty prints for %s", self.class_name)
 
         # equation symbols for pretty printing
         self.f, self.g = Matrix([]), Matrix([])
@@ -362,7 +366,7 @@ class SymProcessor:
 
         self.calls.init_latex = init_latex
 
-    def generate_pycode(self, pycode_path):
+    def generate_pycode(self, pycode_path, yapf_pycode):
         """
         Create output source code file for generated code.
 
@@ -380,12 +384,13 @@ from numpy import greater_equal, less_equal, greater, less, equal   # NOQA
 from numpy import logical_and, logical_or, logical_not              # NOQA
 from numpy import array, real, imag, conj, angle, radians           # NOQA
 from numpy import arcsin, arccos, arctan, arctan2                   # NOQA
-from numpy import log  # NOQA
+from numpy import log                                               # NOQA
 
-from andes.core.npfunc import *  # NOQA
+from andes.core.npfunc import *                                     # NOQA
 
 
 """
+        yf = yapf_pycode
 
         with open(file_path, 'w') as f:
             f.write(header)
@@ -394,30 +399,30 @@ from andes.core.npfunc import *  # NOQA
             f.write(f'md5 = "{self.calls.md5}"\n\n')
 
             # equations
-            f.write(self._rename_func(self.calls.f, 'f_update'))
-            f.write(self._rename_func(self.calls.g, 'g_update'))
+            f.write(self._rename_func(self.calls.f, 'f_update', yf))
+            f.write(self._rename_func(self.calls.g, 'g_update', yf))
 
             # jacobians
             for name in self.calls.j:
-                f.write(self._rename_func(self.calls.j[name], f'{name}_update'))
+                f.write(self._rename_func(self.calls.j[name], f'{name}_update', yf))
 
             # initialization: assignments
             for name in self.calls.ia:
-                f.write(self._rename_func(self.calls.ia[name], f'{name}_ia'))
+                f.write(self._rename_func(self.calls.ia[name], f'{name}_ia', yf))
             for name in self.calls.ii:
-                f.write(self._rename_func(self.calls.ii[name], f'{name}_ii'))
+                f.write(self._rename_func(self.calls.ii[name], f'{name}_ii', yf))
             for name in self.calls.ij:
-                f.write(self._rename_func(self.calls.ij[name], f'{name}_ij'))
+                f.write(self._rename_func(self.calls.ij[name], f'{name}_ij', yf))
 
             # services
             for name in self.calls.s:
-                f.write(self._rename_func(self.calls.s[name], f'{name}_svc'))
+                f.write(self._rename_func(self.calls.s[name], f'{name}_svc', yf))
 
             # variables
             for name in dilled_vars:
                 f.write(f'\n{name} = ' + pprint.pformat(self.calls.__dict__[name]))
 
-    def _rename_func(self, func, func_name):
+    def _rename_func(self, func, func_name, yapf_pycode=False):
         """
         Rename the function name and return source code.
 
@@ -434,7 +439,7 @@ from andes.core.npfunc import *  # NOQA
         # remove `Indicator`
         src = src.replace("Indicator", "")
 
-        if self.parent.system.config.yapf_pycode:
+        if yapf_pycode:
             try:
                 from yapf.yapflib.yapf_api import FormatCode
                 src = FormatCode(src, style_config='pep8')[0]  # drop the encoding `None`
@@ -588,6 +593,17 @@ from andes.core.npfunc import *  # NOQA
         self.calls.ii_args = ii_args
         self.calls.ij_args = ij_args
 
+    def get_system_config(self, name):
+        """
+        Helper function for obtaining system config.
+        If System is None, return None.
+        """
+
+        if hasattr(self.parent.system, 'config'):
+            return self.parent.system.config.__dict__[name]
+
+        return None
+
 
 def _store_deps(name, sympified, vars_int_dict, deps):
     """
