@@ -1,4 +1,6 @@
 import os
+from typing import Iterable
+
 from andes.shared import np
 
 
@@ -13,12 +15,19 @@ def dump_data(text, header, rowname, data, file, width=14, precision=5):
             if Text:
                 fid.writelines(Text)
 
+            # determine the width for the first column (usually names)
+            width_first = width
+            if isinstance(Rowname, Iterable) and len(Rowname) > 0:
+                for item in Rowname:
+                    if isinstance(item, Iterable) and len(item) > width_first:
+                        width_first = len(item)
+
             # Write Header
             if Header:
                 ncol = len(Header)
-                s = ' ' * width
+                s = ' ' * width_first
                 s += '{:>{width}s}' * ncol + '\n'
-                fid.writelines(s.format(*Header, width=width))  # Mind the asterisk
+                fid.writelines(s.format(*Header, width=width))
                 fid.write('\n')
 
             # Append Rowname to Data
@@ -26,20 +35,21 @@ def dump_data(text, header, rowname, data, file, width=14, precision=5):
             if Rowname is not None:
                 ncol = 0
                 for idx, item in enumerate(Rowname):  # write by row as always
-                    if not Data:
+                    if Data is None:
                         out = ''
-                    elif isinstance(Data, (int, float)):
+                    elif isinstance(Data, (int, float, str)):
                         out = [Data]
-                    elif isinstance(Data[0], (int, float)):  # is a list of numbers
-                        out = [Data[idx]]
-                    elif isinstance(Data[0], (list, np.ndarray)):  # list of list in Data
-                        ncol = len(Data)
-                        out = [Data[i][idx] for i in range(ncol)]
+                    elif isinstance(Data, (list, tuple, np.ndarray)):
+                        if isinstance(Data[0], (int, float)):  # is a list of numbers
+                            out = [Data[idx]]
+                        elif isinstance(Data[0], (list, np.ndarray)):  # list of list in Data
+                            ncol = len(Data)
+                            out = [Data[i][idx] for i in range(ncol)]
                     else:
                         print(Data)
                         print('Unexpected Data during output, in formats/txt.py')
 
-                    s = '{:{width}s}'  # for row header
+                    s = '{:{width_first}s}'  # for row header
                     for ii, col in enumerate(out):
                         if isinstance(col, (int, float)):
                             s += '{:>{width}.{precision}g}'
@@ -56,5 +66,5 @@ def dump_data(text, header, rowname, data, file, width=14, precision=5):
 
                     fid.write(
                         s.format(
-                            str(item), *out, width=width, precision=precision))
+                            str(item), *out, width_first=width_first, width=width, precision=precision))
             fid.write('\n')
