@@ -153,31 +153,31 @@ class DGPRCTBaseData(ModelData):
                             unit='p.u.',
                             )
 
-        self.TVl1 = NumParam(default=2,
+        self.Tvl1 = NumParam(default=2,
                              tex_name=r'T_{vl1}',
                              info='Stand time for (vl2, vl1)',
                              non_negative=True,
                              )
 
-        self.TVl2 = NumParam(default=1,
+        self.Tvl2 = NumParam(default=1,
                              tex_name=r'T_{vl2}',
                              info='Stand time for (vl3, vl2)',
                              non_negative=True,
                              )
 
-        self.TVl3 = NumParam(default=0.16,
+        self.Tvl3 = NumParam(default=0.16,
                              tex_name=r'T_{vl3}',
                              info='Stand time for (vl4, vl3)',
                              non_negative=True,
                              )
 
-        self.TVu1 = NumParam(default=1,
+        self.Tvu1 = NumParam(default=1,
                              tex_name=r'T_{vu1}',
                              info='Stand time for (vu1, vu2)',
                              non_negative=True,
                              )
 
-        self.TVu2 = NumParam(default=0.16,
+        self.Tvu2 = NumParam(default=0.16,
                              tex_name=r'T_{vu2}',
                              info='Stand time for (vu2, vu3)',
                              non_negative=True,
@@ -196,7 +196,7 @@ class DGPRCTBaseModel(Model):
     def __init__(self, system, config):
         Model.__init__(self, system, config)
         self.flags.tds = True
-        self.group = 'DG'
+        self.group = 'DGProtection'
 
         self.bus = ExtParam(model='DG', src='bus',
                             indexer=self.dev,
@@ -271,6 +271,8 @@ class DGPRCTBaseModel(Model):
                              export=False,
                              e_str='- ue * (fn * f)',
                              info='Frequency measure lock',
+                             ename='fHzl',
+                             tex_ename='f_{Hzl}',
                              )
         # TODO: add fflag option 2: block the source signal in protection
 
@@ -296,6 +298,8 @@ class DGPRCTBaseModel(Model):
                              export=False,
                              e_str='- ue * (Pext + Pref + Pdrp)',
                              info='Active power lock',
+                             ename='Pneg',
+                             tex_ename='P_{neg}',
                              )
 
         self.Qdrp = ExtAlgeb(model='DG', src='Qdrp',
@@ -313,6 +317,8 @@ class DGPRCTBaseModel(Model):
                              export=False,
                              e_str='- ue * (Qdrp + Qref)',
                              info='Reactive power lock',
+                             ename='Qneg',
+                             tex_ename='Q_{neg}',
                              )
 
         # TODO: apply ExtState here
@@ -424,37 +430,37 @@ class VProtect:
                             )
 
         # Voltage deviation time continuity check
-        self.IAWVl1 = IntegratorAntiWindup(u='LVl1_zi * (1 - res) - TVl1 / Tres * res',
+        self.IAWVl1 = IntegratorAntiWindup(u='LVl1_zi * (1 - res) - Tvl1 / Tres * res',
                                            T=1, K=1, y0='0',
-                                           lower=self.zero, upper=self.TVl1,
+                                           lower=self.zero, upper=self.Tvl1,
                                            info='condition check for (Vl3, Vl1)',
                                            no_warn=True,
                                            )
 
-        self.IAWVl2 = IntegratorAntiWindup(u='LVl2_zi * (1 - res) - TVl2 / Tres * res',
+        self.IAWVl2 = IntegratorAntiWindup(u='LVl2_zi * (1 - res) - Tvl2 / Tres * res',
                                            T=1, K=1, y0='0',
-                                           lower=self.zero, upper=self.TVl2,
+                                           lower=self.zero, upper=self.Tvl2,
                                            info='condition check for (Vl3, Vl2)',
                                            no_warn=True,
                                            )
 
-        self.IAWVl3 = IntegratorAntiWindup(u='LVl2_zi * (1 - res) - TVl3 / Tres * res',
+        self.IAWVl3 = IntegratorAntiWindup(u='LVl2_zi * (1 - res) - Tvl3 / Tres * res',
                                            T=1, K=1, y0='0',
-                                           lower=self.zero, upper=self.TVl2,
+                                           lower=self.zero, upper=self.Tvl2,
                                            info='condition check for (Vl3, Vl2)',
                                            no_warn=True,
                                            )
 
-        self.IAWVu1 = IntegratorAntiWindup(u='LVu1_zi * (1 - res) - TVu1 / Tres * res',
+        self.IAWVu1 = IntegratorAntiWindup(u='LVu1_zi * (1 - res) - Tvu1 / Tres * res',
                                            T=1, K=1, y0='0',
-                                           lower=self.zero, upper=self.TVu1,
+                                           lower=self.zero, upper=self.Tvu1,
                                            info='condition check for (Vu1, Vu3)',
                                            no_warn=True,
                                            )
 
-        self.IAWVu2 = IntegratorAntiWindup(u='LVu2_zi * (1 - res) - TVu2 / Tres * res',
+        self.IAWVu2 = IntegratorAntiWindup(u='LVu2_zi * (1 - res) - Tvu2 / Tres * res',
                                            T=1, K=1, y0='0',
-                                           lower=self.zero, upper=self.TVu2,
+                                           lower=self.zero, upper=self.Tvu2,
                                            info='condition check for (Vu2, Vu3)',
                                            no_warn=True,
                                            )
@@ -481,13 +487,15 @@ class DGPRCT1(DGPRCTBaseData, DGPRCT1Model):
     """
     DGPRCT1 model, follow IEEE-1547-2018. DGPRCT stands for DG protection.
 
+    A demo is provided: examples/demonstration/1.1 demo_DGPRCT1.ipynb
+
     Target device (limited to DG group) ``Psum`` and ``Qsum`` will decrease to zero
     immediately when frequency/voltage protection flag is raised. Once the lock is
     released, ``Psum`` and ``Qsum`` will return to normal immediately.
 
     DG group base model ``PVD1`` already has a degrading function which is used to
-    degrade output under abnormal condition. it is recommended to turn off it by setting
-    `tren = 0`.
+    degrade output under abnormal condition. it is recommended to turn it off by setting
+    `recflag = 0`.
 
     ``fen`` and ``Ven`` are protection enabling parameters. 1/0 is on/off.
 
@@ -498,7 +506,7 @@ class DGPRCT1(DGPRCTBaseData, DGPRCT1Model):
 
     Protection sensors (e.g., IAWfl1) are instances of ``IntergratorAntiWindup``. All
     the protection sensors will be reset after ``ue`` returns to 0.
-    Resetting takes `Tres` to finish.
+    Resetting action takes `Tres` to finish.
 
     The model does not check the shedding points sequence.
     The input parameters are required to satisfy ``fl3 < fl2 < fl1 < fu1 < fu2 < fu3``,
@@ -512,11 +520,11 @@ class DGPRCT1(DGPRCTBaseData, DGPRCT1Model):
     `(fu2, fu3), Tfu2` [(61.5, 70.0), 10s]\n
 
     Voltage (p.u.):\n
-    `(vl4, vl3), TVl3` [(0.10, 0.45), 0.16s]\n
-    `(vl3, vl2), TVl2` [(0.45, 0.60), 1s]\n
-    `(vl2, vl1), TVl1` [(0.60, 0.88), 2s]\n
-    `(vu1, vu2), TVu1` [(1.10, 1.20), 1s]\n
-    `(vu2, vu3), TVu2` [(1.20, 2.00), 0.16s]\n
+    `(vl4, vl3), Tvl3` [(0.10, 0.45), 0.16s]\n
+    `(vl3, vl2), Tvl2` [(0.45, 0.60), 1s]\n
+    `(vl2, vl1), Tvl1` [(0.60, 0.88), 2s]\n
+    `(vu1, vu2), Tvu1` [(1.10, 1.20), 1s]\n
+    `(vu2, vu3), Tvu2` [(1.20, 2.00), 0.16s]\n
 
     Reference:
 
@@ -551,18 +559,23 @@ class DGPRCTExtModel(DGPRCTBaseModel, fProtect, VProtect):
 
 class DGPRCTExt(DGPRCTBaseData, DGPRCTExtModel):
     """
-    DGPRCT External model, follow IEEE-1547. DGPRCT stands for DG protection.
+    DGPRCT External model, follow IEEE-1547-2018. DGPRCT stands for DG protection.
 
-    Similar to DGPRCT1, but the measured voltage is retrived from outside.
+    Similar to DGPRCT1, but the measured voltage can be manipulated.
 
-    DG group base model ``PVD1`` already has a degrading function which is used to
-    degrade output under abnormal condition. it is recommended to turn off it by setting
-    `tren = 0`.
+    A demo is provided: examples/demonstration/1.2 demo_DGPRCTExt.ipynb
+
+    This model can be applied to co-simulation, where you can input the external votage signal
+    into ANDES. If no extertal value is applied, the votalge will remain as the initialized value.
 
     Target device (limited to DG group) ``Psum`` and ``Qsum`` will decrease to zero
     immediately when frequency/voltage protection flag is raised. Once the lock is
     released, ``Psum`` and ``Qsum`` will return to normal immediately.
 
+    DG group base model ``PVD1`` already has a degrading function which is used to
+    degrade output under abnormal condition. it is recommended to turn it off by setting
+    `recflag = 0`.
+
     ``fen`` and ``Ven`` are protection enabling parameters. 1/0 is on/off.
 
     ``ue`` is lock flag signal.
@@ -570,13 +583,13 @@ class DGPRCTExt(DGPRCTBaseData, DGPRCTExtModel):
     It should be noted that, the lock only lock the ``fHz`` (frequency read value)
     of DG model. The source values (which come from ``BusFreq`` `f` remain unchanged.)
 
-    Protection sensors (like IAWfl1) are realized by ``IntergratorAntiWindup``. All
-    the protection sensors will be reset after ``ue`` return to 0. Reset action takes
-    `Tres` to finish.
+    Protection sensors (e.g., IAWfl1) are instances of ``IntergratorAntiWindup``. All
+    the protection sensors will be reset after ``ue`` returns to 0.
+    Resetting action takes `Tres` to finish.
 
     The model does not check the shedding points sequence.
-    The input parameters are required to satisfy `fl3 < fl2 < fl1 < fu1 < fu2 < fu3`,
-    and `ul4 < ul3 < ul2 < ul1 < uu1 < uu2 < uu3`.
+    The input parameters are required to satisfy ``fl3 < fl2 < fl1 < fu1 < fu2 < fu3``,
+    and ``ul4 < ul3 < ul2 < ul1 < uu1 < uu2 < uu3``.
 
     Default settings:\n
     Frequency (Hz):\n
@@ -586,11 +599,18 @@ class DGPRCTExt(DGPRCTBaseData, DGPRCTExtModel):
     `(fu2, fu3), Tfu2` [(61.5, 70.0), 10s]\n
 
     Voltage (p.u.):\n
-    `(vl4, vl3), TVl3` [(0.10, 0.45), 0.16s]\n
-    `(vl3, vl2), TVl2` [(0.45, 0.60), 1s]\n
-    `(vl2, vl1), TVl1` [(0.60, 0.88), 2s]\n
-    `(vu1, vu2), TVu1` [(1.10, 1.20), 1s]\n
-    `(vu2, vu3), TVu2` [(1.20, 2.00), 0.16s]\n
+    `(vl4, vl3), Tvl3` [(0.10, 0.45), 0.16s]\n
+    `(vl3, vl2), Tvl2` [(0.45, 0.60), 1s]\n
+    `(vl2, vl1), Tvl1` [(0.60, 0.88), 2s]\n
+    `(vu1, vu2), Tvu1` [(1.10, 1.20), 1s]\n
+    `(vu2, vu3), Tvu2` [(1.20, 2.00), 0.16s]\n
+
+    Reference:
+
+    NERC. Bulk Power System Reliability Perspectives on the Adoption of IEEE 1547-2018.
+    March 2020. Available:
+
+    https://www.nerc.com/comm/PC_Reliability_Guidelines_DL/Guideline_IEEE_1547-2018_BPS_Perspectives.pdf
     """
 
     def __init__(self, system, config):
