@@ -174,6 +174,8 @@ class IEEEG1Model(TGBase):
                             tex_name=r'\tau_{m2}',
                             e_str='zsyn2 * ue * (PLP - tm02)',
                             info='Mechanical power to syn2',
+                            ename='tm2',
+                            tex_ename=r'\tau_{m2}',
                             )
 
         self.wd = Algeb(info='Generator under speed',
