@@ -60,7 +60,9 @@ class WTDSModel(Model):
 
         self.wge = ExtAlgeb(model='RenExciter', src='wg', indexer=self.ree,
                             export=False,
-                            e_str='-1.0 + s1_y'
+                            e_str='-1.0 + s1_y',
+                            ename='wg',
+                            tex_ename=r'\omega_g',
                             )
 
         self.Pe = ExtAlgeb(model='RenGen', src='Pe', indexer=self.reg, export=False,
